#! /usr/bin/python3
# -*- coding: utf-8 -*- 
# @File     :my.py
# @Time     :2021/2/8
# @Author   :jiawei.li
# @Software :PyCharm
# @Desc     :None

#! /usr/bin/python3
# -*- coding: utf-8 -*-
# @File     :my.py
# @Time     :2021/2/4
# @Author   :jiawei.li
# @Software :PyCharm
# @Desc     :None

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import sklearn
fig = plt.figure()
fig.set(alpha=0.2)

def fittransform(inputs, cols):
    for col in cols:
        X = inputs[col]
        y = sklearn.utils.validation.column_or_1d(X, warn=True)
        label_encoder = sklearn.preprocessing.LabelEncoder.fit(list(X) + ['unknown'])
        classes = label_encoder.classes_
        y = sklearn.utils.validation.column_or_1d(y, warn=True)
        indices = np.isin(y, classes)

        y_transformed = np.searchsorted(classes, y)
        y_transformed[~indices] = -1
        inputs[col] = y_transformed
    return inputs

def timeMapper(inputs, cols, result_column, time_interval_min):
    outputs = inputs
    def colmapper(x):
        return x % (3600 * 24) // (time_interval_min * 60)
    for idx, col in enumerate(cols):
        X = outputs[col]
        mapped_col = X.apply(colmapper).values
        mapped_col_name = result_column + '_' + str(idx)
        outputs[mapped_col_name] = mapped_col
    return outputs



#! /usr/bin/python3
# -*- coding: utf-8 -*- 
# @File     :main.py
# @Time     :2021/2/7
# @Author   :jiawei.li
# @Software :PyCharm
# @Desc     :None


# from TEST_ETAE.main import infer
import pandas as pd
import json
import sys
from ETAES.operations import excute_pipeline, build_pipeline, build_configurations

#
# config_path = 'TEST_ETAE/cfgs/config.yaml'
# waybills_df = pd.read_csv('TEST_ETAE/data/waybills.csv')
# waybills_df.drop(['Unnamed: 0', 'delivery_time'], axis=1, inplace=True)
# waybills_str = waybills_df[:3].to_json(orient="records")
# inputs = json.loads(waybills_str)
# kwargs = build_configurations(config_path)
# kwargs['basic']['task_id'] = '1612750425'

def init(kwargs, inputs):
    return build_pipeline(kwargs, inputs)

# TODO: 将infer和init区分开
def infer(kwargs, inputs):
    pipeline = init(kwargs, inputs)
    return excute_pipeline(pipeline)

# infer()
# if __name__ == '__main__':
#     waybills_df = pd.read_csv('TEST_ETAE/data/waybills.csv')
#     waybills_df.drop(['Unnamed: 0', 'delivery_time'], axis=1, inplace=True)
#     waybills_str = waybills_df[:3].to_json(orient="records")
#     waybills_js = json.loads(waybills_str)
#
#     # def find_config_from_taskid(task_id):
#     #     config_path = 'cfgs/config.yaml'
#     #     return build_configurations(config_path)
#     #
#     # task_id = '1612691303'
#     # kwargs = find_config_from_taskid(task_id)
#     # kwargs['basic']['task_id'] = task_id
#     #
#     # result = infer(kwargs, waybills_js)
#     # print(result)
#
#     _, config_path = sys.argv
#     kwargs = build_configurations(config_path)
#     if kwargs['basic']['status'] == 'online':
#         kwargs['basic']['task_id'] = '1612750425'
#         waybills_df = pd.read_csv('TEST_ETAE/data/waybills.csv')
#         waybills_df.drop(['Unnamed: 0'], axis=1, inplace=True)
#         waybills_str = waybills_df[:2].to_json(orient="records")
#         waybills_js = json.loads(waybills_str)
#         excute_pipeline(kwargs, waybills_js)
#     else:
#         excute_pipeline(kwargs, js=None)


#! /usr/bin/python3
# -*- coding: utf-8 -*- 
# @File     :__init__.py.py
# @Time     :2021/2/8
# @Author   :jiawei.li
# @Software :PyCharm
# @Desc     :None

from .my import *

__all__ = [
    'fittransform',
    'timeMapper'
]